@@ -22,7 +22,8 @@ from .serialize import dumps
 from .constants import id_sep, end_of_message
 from .exceptions import exception as get_exception
 from .message import Message
-from .objects import Tag
+from .objects import Tag, Node, Map
+from .funcs import top
 from . import __version__
 
 class TestOutput(object):
@@ -117,6 +118,21 @@ class TestOutput(object):
             except:
                 return repr(v)
 
+        def map_fields(obj, visited):
+            visited.add(obj.node)
+            return rstrip_list([
+                rstrip_list(object_fields(Node.create(obj.node))),
+                rstrip_list([map_fields(
+                    Map(n) if n in visited else getattr(n.func, "map", Map(n)), visited)
+                        for n in obj.nexts]) if obj.nexts else None,
+                rstrip_list([map_fields(
+                    Map(n) if n in visited else getattr(n.func, "map", Map(n)), visited)
+                        for n in obj.ins]) if obj.ins else None,
+                rstrip_list([map_fields(
+                    Map(n) if n in visited else getattr(n.func, "map", Map(n)), visited)
+                        for n in obj.outs]) if obj.outs else None,
+            ])
+
         msg = dumps(rstrip_list([
             self.test.name,
             round(self.test.start_time, settings.time_resolution),
@@ -130,6 +146,8 @@ class TestOutput(object):
             [rstrip_list(object_fields(user)) for user in self.test.users],
             [rstrip_list(object_fields(ticket)) for ticket in self.test.tickets],
             rstrip_list(object_fields(self.test.examples)) if self.test.examples else None,
+            rstrip_list(object_fields(self.test.node)) if self.test.node else None,
+            map_fields(self.test.map, set()) if (self.test.map and self.test is top()) else None
         ]))[1:-1]
         self.message(Message.TEST, msg, rtime=0)
 
